pynrc.detops
============

.. automodule:: pynrc.detops

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      config2
      create_detops
      nrc_header
      tuples_to_dict
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: custom-class-template.rst
   
      det_timing
      multiaccum
   
   

   
   
   



